============
Installation
============

---------------
Getting started
---------------

These instructions will get you a copy of the ``stuweparser`` package on your
local machine. If you only want to use ``stuweparser`` as a python package
use ``pip3`` in order to install it into your python3 environment. If you want
to inspect and change the code download and install it via ``git clone`` and
``python3 setup.py``. For details see below.


-------------
Prerequisites
-------------
You need python 3.4 or newer and git installed on your machine. We recommend to
install `Minicoda <https://conda.io/miniconda.html>`_ before installing
``stuweparser`` or to create a virtualenv within your personal folder.


----------
Installing
----------
If you want to use the package you can install the package by running

.. code:: bash

    git clone https://github.com/trybnetic/stuweparser.git
    cd stuweparser
    python3 setup.py install
